package Dist::Zilla::Plugin::AlienBase;

use 5.014;
use Moose;

# ABSTRACT: Use Alien::Base with Dist::Zilla
our $VERSION = '0.12'; # VERSION


__PACKAGE__->meta->make_immutable;

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Dist::Zilla::Plugin::AlienBase - Use Alien::Base with Dist::Zilla

=head1 VERSION

version 0.12

=head1 SYNOPSIS

 [AlienBase]

=head1 AUTHOR

Graham Ollis <plicease@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by Graham Ollis.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
